package me.hammerle.exceptions;

import java.util.ArrayList;
import me.hammerle.code.Code;
import me.hammerle.code.Script;

public class SnuviException extends RuntimeException
{
    private final Exception ex;
    private final String scriptName;
    private final ArrayList<String> code;
    private final int line;
    
    public SnuviException(Exception ex, String scriptName, int line, String code)
    {
        this.ex = ex;
        this.scriptName = scriptName;
        this.code = new ArrayList<>();
        addCode(code);
        this.line = line;
    }
    
    private void addCode(String code)
    {
        if(code != null)
        {
            this.code.add(code);
        }
    }
    
    public SnuviException(Exception ex, String scriptName, String code)
    {
        this(ex, scriptName, -1, code);
    }
    
    public SnuviException(Exception ex, String scriptName, int line)
    {
        this(ex, scriptName, line, null);
    }
    
    public SnuviException(Exception ex, Script sc)
    {
        this(ex, sc.getName(), sc.getActiveRealCodeLine());
        int i = sc.getActiveCodeLine();
        if(i != -1)
        {
            for(Code c : sc.getCode(i))
            {
                this.code.add(c.toString());
            }
        }
    }
    
    public SnuviException(Exception ex)
    {
        this(ex, null, -1);
    }
    
    public Exception getOriginalException()
    {
        return ex;
    }
    
    public int getLine()
    {
        return line;
    }
    
    public String getCode()
    {
        if(code.isEmpty())
        {
            return null;
        }
        return code.get(0);
    }
    
    public ArrayList<String> getWholeCode()
    {
        return code;
    }
    
    public String getScriptName()
    {
        return scriptName;
    }
}
